/****************************************************************************************
    Copyright 2004 uja
    Copyright 2004 Trolltech (Qt3)

    This file is part of ujagames lib which runs under GPL.
*****************************************************************************************/

#include "window.h"
#include <qfont.h>
// ================================================================================================

window::window(QWidget *parent,char* name): QHBox(parent,name)
{
  setBackgroundColor(QColor(BACKGR0));
  setBackgroundPixmap(QPixmap(BACKPIX0));
  QPalette my_pal=QPalette(this->palette());
  my_pal.setColor(QColorGroup::Light,RANDHCOLOR);
  my_pal.setColor(QColorGroup::Dark,RANDDCOLOR);
  this->setPalette(my_pal);

  QHBox* centerwig=new QHBox(this);
  centerwig->setBackgroundColor(QColor(BACKGR0));
  centerwig->setBackgroundPixmap(QPixmap(BACKPIX0));
  centerwig->setBackgroundOrigin(WindowOrigin);
  centerwig->setMaximumSize(800,600);

// 1.Spalte: Spielbrett:
  my_view=new viewport(centerwig,"playfield"); // QCanvasView/ScrollView, Hover, Klick

// 2.Spalte: berschrift, Messagearea, Anzeigen und Wahlmglichkeiten:
  QVBox* spalte2=new QVBox(centerwig);
  spalte2->setBackgroundOrigin(WindowOrigin);
  spalte2->setBackgroundColor(QColor(BACKGR0));
  spalte2->setMaximumHeight(YMAX*DY+2+OFY);
  spalte2->setMargin(4);

// Ueberschrift:
  QFont* my_font=new QFont();
  my_font->setFamily("URW Chancery L");
  my_font->setStyleStrategy(QFont::PreferAntialias);
  my_font->setStyleStrategy(QFont::PreferOutline);
  my_font->setPointSize(32); my_font->setWeight(4);
  QLabel* p_ue =new QLabel(spalte2); p_ue->setText(PROGNAME); 
  p_ue->setFont(*my_font); p_ue->setPaletteForegroundColor(COLOR0);
  p_ue->setBackgroundOrigin(WindowOrigin);
  p_ue->setPaletteBackgroundColor(QColor(BACKGR0));
  p_ue->setBackgroundPixmap(QPixmap(BACKPIX0));

  p_messi=new QLabel(spalte2);
  p_messi->setPaletteForegroundColor(COLOR0);
  p_messi->setBackgroundOrigin(WindowOrigin);
  p_messi->setPaletteBackgroundColor(QColor(BACKGR0));
  p_messi->setBackgroundPixmap(QPixmap(BACKPIX0));

// Anzeigentafel als 2-spaltiges Gitter
  QGrid* p_anzeigen=new QGrid(2,spalte2,"anzeigen");
  p_anzeigen->setPaletteBackgroundColor(QColor(BACKGR2));
  p_anzeigen->setPaletteForegroundColor(COLOR2);
  p_anzeigen->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_anzeigen->setMinimumSize(160,64);
  p_anzeigen->setFrameShadow(Sunken);
  p_anzeigen->setFrameShape(Box);
  p_anzeigen->setMargin(2);

  // Daten einfuellen:
  QLabel* p_llevel  =new QLabel(_LEVEL, p_anzeigen); p_level=new QLabel(p_anzeigen); p_level->setMinimumWidth(192);
  QLabel* p_lrest   =new QLabel(_REST,  p_anzeigen); p_rest=new QLabel(p_anzeigen);
  QLabel* p_lzeit   =new QLabel(_ZEIT,  p_anzeigen); p_zeit=new QLabel(p_anzeigen);
  QLabel* p_lpunkte =new QLabel(_PUNKTE,p_anzeigen); p_punkte=new QLabel(p_anzeigen);

  p_llevel->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_level->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_lzeit->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_lrest->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_zeit->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_rest->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_lpunkte->setBackgroundPixmap(QPixmap(BACKPIX2));
  p_punkte->setBackgroundPixmap(QPixmap(BACKPIX2));


  // Steuerung:
  QGrid* p_steuer=new QGrid(2,spalte2,"Knoeppe");
  p_steuer->setBackgroundOrigin(WindowOrigin);
  p_steuer->setPaletteBackgroundColor(QColor(BACKGR0));
  p_steuer->setPaletteBackgroundPixmap(QPixmap(BACKPIX0));
  p_steuer->setMaximumHeight(64);

  p_neu=new QPushButton(_NEU,p_steuer);
  p_neu->  setPaletteBackgroundColor(QColor(BACKGR2));
  p_neu->setPaletteBackgroundPixmap(QPixmap(PAPERBILD));

  p_restart=new QPushButton(_RESTART,p_steuer);
  p_restart->setPaletteBackgroundColor(QColor(BACKGR2));
  p_restart->setPaletteBackgroundPixmap(QPixmap(PAPERBILD));

  p_pause=new QPushButton(_PAUSECONT,p_steuer);
  p_pause->setPaletteBackgroundColor(QColor(BACKGR2));
  p_pause->setPaletteBackgroundPixmap(QPixmap(PAPERBILD));

  p_aufgeben=new QPushButton(_AUFGEBEN,p_steuer);
  p_aufgeben->setPaletteBackgroundColor(QColor(BACKGR2));
  p_aufgeben->setPaletteBackgroundPixmap(QPixmap(PAPERBILD));

  set_messi("Messages");
  set_level("Levelname");
  set_zeit(999);
  set_punkte(0);
}

// Slots: - nicht benoetigte Slots stoeren erstmal nicht
void window::set_punkte(int p)        { p_punkte->setNum(p); }
void window::set_level(QString p)     { p_level->setText(p); }
void window::set_messi(QString p)     { p_messi->setText(p); }
void window::set_zeit(int p)          { p_zeit->setNum(p);   }
void window::set_rest(int p)          { p_rest->setNum(p);   }
void window::pause(bool p) { if (p) p_pause->setText(_PAUSE); else p_pause->setText(_WEITER); }
// ==================================================================================================================

void window::about()
{ QString t="<h3>Fleur II 1.8</h3><p>A KlickiBunti game, the follower of Fleur, where you have to make connections "; 
  t=t+" to 2 equal stones by a line with max. 2 turns in it, this one with obstacles on the board.</p>";
  t=t+"<p>Author: uja (Ulrike Jahnke-Soltau) 2005 - License: GPL v2</p>";
  t=t+"<p>For more KlickiBuntis please visit our website<br>http://www.gamecraft.de</p>";
  QMessageBox::about(this,"Info",t);
}
